@@ -1,10 +1,10 @@
+from __future__ import annotations
 from enum import Enum
-from typing import Dict, Type
 
 from zodipy._components import Component, Cloud, Band, Ring, Feature
 
 
-class Label(Enum):
+class CompLabel(Enum):
     """Labels representing the six Zodiacal components in the K98 model."""
 
     CLOUD = "cloud"
@@ -15,11 +15,11 @@ class Label(Enum):
     FEATURE = "feature"
 
 
-LABEL_TO_CLASS: Dict[Label, Type[Component]] = {
-    Label.CLOUD: Cloud,
-    Label.BAND1: Band,
-    Label.BAND2: Band,
-    Label.BAND3: Band,
-    Label.RING: Ring,
-    Label.FEATURE: Feature,
+LABEL_TO_CLASS: dict[CompLabel, type[Component]] = {
+    CompLabel.CLOUD: Cloud,
+    CompLabel.BAND1: Band,
+    CompLabel.BAND2: Band,
+    CompLabel.BAND3: Band,
+    CompLabel.RING: Ring,
+    CompLabel.FEATURE: Feature,
 }
